@@ -1,77 +1,80 @@
 import os
 import sys
 import time
+
 import periphery
-from .asserts import AssertRaises
+from .test import ptest, pokay, passert, AssertRaises
 
 if sys.version_info[0] == 3:
     raw_input = input
 
+
 led_name = None
 
 
 def test_arguments():
-    print("Starting arguments test...")
+    ptest()
 
     # Invalid open types
-    with AssertRaises(TypeError):
+    with AssertRaises("invalid open types", TypeError):
         periphery.LED("abc", "out")
-    with AssertRaises(TypeError):
+    with AssertRaises("invalid open types", TypeError):
         periphery.LED(100, 100)
 
-    print("Arguments test passed.")
-
 
 def test_open_close():
-    print("Starting open/close test...")
+    ptest()
 
     # Open non-existent LED
-    with AssertRaises(LookupError):
+    with AssertRaises("non-existent led", LookupError):
         periphery.LED("invalid_led_XXX", 0)
 
     # Open legitimate LED
     led = periphery.LED(led_name, 0)
-    assert led.name == led_name
-    assert led.fd > 0
-    assert led.max_brightness > 0
+    passert("property name", led.name == led_name)
+    passert("fd >= 0", led.fd >= 0)
+    passert("max_brightness > 0", led.max_brightness > 0)
 
     # Set brightness to True, check brightness
     led.write(True)
     time.sleep(0.01)
-    assert led.read() == led.max_brightness
+    passert("brightness is max", led.read() == led.max_brightness)
 
     # Set brightness to False, check brightness
     led.write(False)
     time.sleep(0.01)
-    assert led.read() == 0
+    passert("brightness is zero", led.read() == 0)
 
     # Set brightness to 1, check brightness
     led.write(1)
     time.sleep(0.01)
-    assert led.read() >= 1
+    passert("brightness is non-zero", led.read() >= 1)
 
     # Set brightness to 0, check brightness
     led.write(0)
     time.sleep(0.01)
-    assert led.read() == 0
+    passert("brightness is zero", led.read() == 0)
 
     # Set brightness to 1, check brightness
     led.brightness = 1
     time.sleep(0.01)
-    assert led.brightness >= 1
+    passert("brightness is non-zero", led.brightness >= 1)
 
     # Set brightness to 0, check brightness
     led.brightness = 0
     time.sleep(0.01)
-    assert led.brightness == 0
+    passert("brightness is zero", led.brightness == 0)
 
     led.close()
 
-    print("Open/close test passed.")
+
+def test_loopback():
+    ptest()
+    # No general way to do a loopback test for I2C without a real component, skipping...
 
 
 def test_interactive():
-    print("Starting interactive test...")
+    ptest()
 
     led = periphery.LED(led_name, False)
 
@@ -79,28 +82,26 @@ def test_interactive():
 
     # Check tostring
     print("LED description: {}".format(str(led)))
-    assert raw_input("LED description looks ok? y/n ") == "y"
+    passert("interactive success", raw_input("LED description looks ok? y/n ") == "y")
 
     # Turn LED off
     led.write(False)
-    assert raw_input("LED is off? y/n ") == "y"
+    passert("interactive success", raw_input("LED is off? y/n ") == "y")
 
     # Turn LED on
     led.write(True)
-    assert raw_input("LED is on? y/n ") == "y"
+    passert("interactive success", raw_input("LED is on? y/n ") == "y")
 
     # Turn LED off
     led.write(False)
-    assert raw_input("LED is off? y/n ") == "y"
+    passert("interactive success", raw_input("LED is off? y/n ") == "y")
 
     # Turn LED on
     led.write(True)
-    assert raw_input("LED is on? y/n ") == "y"
+    passert("interactive success", raw_input("LED is on? y/n ") == "y")
 
     led.close()
 
-    print("Interactive test passed.")
-
 
 if __name__ == "__main__":
     if os.environ.get("CI") == "true":
@@ -124,10 +125,13 @@ if __name__ == "__main__":
 
     led_name = sys.argv[1]
 
-    print("Starting LED tests...")
-
     test_arguments()
+    pokay("Arguments test passed.")
     test_open_close()
+    pokay("Open/close test passed.")
+    test_loopback()
+    pokay("Loopback test passed.")
     test_interactive()
+    pokay("Interactive test passed.")
 
-    print("All LED tests passed.")
+    pokay("All tests passed!")
